@@ -20,11 +20,12 @@
 #include "plotsmodel.h"
 #include <analitza/expression.h>
 #include <analitza/expressionstream.h>
-#include <KStandardDirs>
-#include <KLocalizedString>
 #include <analitzaplot/functiongraph.h>
 #include <analitzaplot/plotsfactory.h>
 #include <QFile>
+#include <QCoreApplication>
+#include <qstandardpaths.h>
+#include <qdir.h>
 
 using namespace Analitza;
 
@@ -32,7 +33,7 @@ PlotsDictionaryModel::PlotsDictionaryModel(QObject* parent)
     : QStandardItemModel(parent)
     , m_currentItem(-1)
 {
-    setHorizontalHeaderLabels(QStringList() << i18nc("@title:column", "Name"));
+    setHorizontalHeaderLabels(QStringList() << QCoreApplication::translate("@title:column", "Name"));
 }
 
 PlotsDictionaryModel::~PlotsDictionaryModel()
@@ -53,7 +54,7 @@ void PlotsDictionaryModel::createDictionary(const QString& file)
             QStandardItem* item = new QStandardItem;
             item->setText(expression.name());
             if(!comments.isEmpty())
-                item->setToolTip(i18nc("dictionary", comments.first().trimmed().toUtf8())); //see Messages.sh for more info
+				item->setToolTip(QCoreApplication::translate("dictionary", comments.first().trimmed().toUtf8())); //see Messages.sh for more info
             item->setData(expression.toString(), ExpressionRole);
             item->setData(file, FileRole);
             appendRow(item);
@@ -64,10 +65,14 @@ void PlotsDictionaryModel::createDictionary(const QString& file)
 
 void PlotsDictionaryModel::createAllDictionaries()
 {
-    QStringList res = KGlobal::dirs()->findAllResources("data", "libanalitza/plots/*.plots");
-    foreach(const QString& f, res) {
-        createDictionary(f);
-    }
+//     QStringList res = KGlobal::dirs()->findAllResources("data", "libanalitza/plots/*.plots");
+	QStringList res = QStandardPaths::locateAll(QStandardPaths::DataLocation, "libanalitza/plots");
+	foreach(const QString& dir, res) {
+		QDir d(dir);
+		foreach(const QString& f, d.entryList(QStringList("*.plots"))) {
+			createDictionary(f);
+		}
+	}
 }
 
 PlotsModel* PlotsDictionaryModel::plotModel()
