@@ -23,7 +23,6 @@
 
 #include <analitza/value.h>
 #include <analitza/vector.h>
-#include <analitza/localize.h>
 #include <QVector3D>
 
 using namespace Analitza;
@@ -50,7 +49,7 @@ class  Fxy : public AbstractSurface/*, static class? better macros FooClass*/
 {
 public:
     CONSTRUCTORS(Fxy)
-    TYPE_NAME(I18N_NOOP("Surface z=F(x,y)"))
+    TYPE_NAME(QT_TR_NOOP("Surface z=F(x,y)"))
     EXPRESSION_TYPE(Analitza::ExpressionType(Analitza::ExpressionType::Lambda).addParameter(
                         Analitza::ExpressionType(Analitza::ExpressionType::Value)).addParameter(
                         Analitza::ExpressionType(Analitza::ExpressionType::Value)).addParameter(
@@ -74,7 +73,7 @@ QVector3D Fxy::fromParametricArgs(double u, double v)
     return QVector3D(u,v,analyzer->calculateLambda().toReal().value());
 }
 
-void Fxy::update(const QVector3D & oppositecorner1, const QVector3D & oppositecorner2)
+void Fxy::update(const QVector3D & /*oppositecorner1*/, const QVector3D & /*oppositecorner2*/)
 {
     buildParametricSurface();
 //     vertices.clear();
@@ -92,7 +91,7 @@ class Fxz : public AbstractSurface/*, static class? better macros FooClass*/
 {
 public:
     CONSTRUCTORS(Fxz)
-    TYPE_NAME(I18N_NOOP("Surface y=F(x,z)"))
+    TYPE_NAME(QT_TR_NOOP("Surface y=F(x,z)"))
     EXPRESSION_TYPE(Analitza::ExpressionType(Analitza::ExpressionType::Lambda).addParameter(
                         Analitza::ExpressionType(Analitza::ExpressionType::Value)).addParameter(
                         Analitza::ExpressionType(Analitza::ExpressionType::Value)).addParameter(
@@ -114,7 +113,7 @@ QVector3D Fxz::fromParametricArgs(double u, double v)
     return QVector3D(u,analyzer->calculateLambda().toReal().value(),v);
 }
 
-void Fxz::update(const QVector3D & oppositecorner1, const QVector3D & oppositecorner2)
+void Fxz::update(const QVector3D & /*oppositecorner1*/, const QVector3D & /*oppositecorner2*/)
 {
     buildParametricSurface();
 }
@@ -125,7 +124,7 @@ class Fyz : public AbstractSurface/*, static class? better macros FooClass*/
 {
 public:
     CONSTRUCTORS(Fyz)
-    TYPE_NAME(I18N_NOOP("Surface x=F(y,z)"))
+    TYPE_NAME(QT_TR_NOOP("Surface x=F(y,z)"))
     EXPRESSION_TYPE(Analitza::ExpressionType(Analitza::ExpressionType::Lambda).addParameter(
                         Analitza::ExpressionType(Analitza::ExpressionType::Value)).addParameter(
                         Analitza::ExpressionType(Analitza::ExpressionType::Value)).addParameter(
@@ -147,7 +146,7 @@ QVector3D Fyz::fromParametricArgs(double u, double v)
     return QVector3D(u,analyzer->calculateLambda().toReal().value(),v);
 }
 
-void Fyz::update(const QVector3D & oppositecorner1, const QVector3D & oppositecorner2)
+void Fyz::update(const QVector3D & /*oppositecorner1*/, const QVector3D & /*oppositecorner2*/)
 {
     buildParametricSurface();
 }
